@@ -23,7 +23,7 @@ try:
     from .prophet import Prophet
 except ModuleNotFoundError:
     logger.warning("Support Facebook Prophet is not available. "
-                   "To enable it, install u8darts[fbprophet] or u8darts[all].")
+                   "To enable it, install u8darts[prophet] or u8darts[all].")
 
 try:
     from .block_rnn_model import BlockRNNModel
