@@ -301,9 +301,16 @@ class ForecastingModel(ABC):
                 forecasts.append(forecast)
 
         if last_points_only:
-            return TimeSeries.from_times_and_values(pd.DatetimeIndex(last_points_times),
-                                                    np.array(last_points_values),
-                                                    freq=series.freq * stride)
+            if series.has_datetime_index:
+                return TimeSeries.from_times_and_values(pd.DatetimeIndex(last_points_times, freq=series.freq * stride),
+                                                        np.array(last_points_values))
+            else:
+                return TimeSeries.from_times_and_values(pd.RangeIndex(start=last_points_times[0],
+                                                                      stop=last_points_times[-1] + 1,
+                                                                      step=1),
+                                                        np.array(last_points_values))
+
+
         return forecasts
 
     def backtest(self,
