@@ -60,37 +60,32 @@ class TimeSeries:
 
         self._time_dim = xa.dims[0]  # how the time dimension is named
 
-        if isinstance(xa.get_index(self._time_dim), pd.DatetimeIndex):
-            # We only sort the xarray if it's indexed by time. That is because sorting with a RangeIndex
-            # transforms the RangeIndex into Int64Index, which messes up things afterwards.
-
-            # The following sorting returns a copy, which we are relying on.
-
-            # As of xarray 0.18.2, this sorting discards the freq of the index for some reason
-            # https://github.com/pydata/xarray/issues/5466
-            self._xa: xr.DataArray = xa.sortby(self._time_dim)
-        else:
-            self._xa = xa.copy()
+        # The following sorting returns a copy, which we are relying on.
+        # As of xarray 0.18.2, this sorting discards the freq of the index for some reason
+        # https://github.com/pydata/xarray/issues/5466
+        self._xa: xr.DataArray = xa.sortby(self._time_dim)
 
         self._time_index = self._xa.get_index(self._time_dim)
 
-        if not isinstance(self._time_index, pd.DatetimeIndex) and not isinstance(self._time_index, pd.RangeIndex):
+        if not isinstance(self._time_index, pd.DatetimeIndex) and not isinstance(self._time_index, pd.Int64Index):
             raise_log(ValueError('The time dimension of the DataArray must be indexed either with a DatetimeIndex,'
-                                 'or with a RangeIndex.'), logger)
+                                 'or with an Int64Index (this can include a RangeIndex).'), logger)
 
         self._has_datetime_index = isinstance(self._time_index, pd.DatetimeIndex)
 
         if self._has_datetime_index:
             freq_tmp = xa.get_index(self._time_dim).freq  # store original freq (see bug of sortby() above).
-            self._freq: pd.DateOffset = freq_tmp
+            self._freq: pd.DateOffset = (freq_tmp if freq_tmp is not None else
+                                         to_offset(self._xa.get_index(self._time_dim).inferred_freq))
             raise_if(self._freq is None,
-                     'The time index of the provided DataArray is missing the freq attribute.',
+                     'The time index of the provided DataArray is missing the freq attribute, and the '
+                     'frequency cannot be inferred.',
                      logger)
 
             self._freq_str: str = self._freq.freqstr
 
             # reset freq inside the xarray index (see bug of sortby() above).
-            self._xa.get_index(self._time_dim).freq = freq_tmp
+            self._xa.get_index(self._time_dim).freq = self._freq
 
             # We have to check manually if the index is complete. Another way could be to rely
             # on `inferred_freq` being present, but this fails for series of length < 3.
@@ -99,7 +94,7 @@ class TimeSeries:
                                                   freq=self._freq).difference(self._time_index)) == 0
 
             raise_if_not(is_index_complete, 'Not all timestamps seem to be present in the time index. Does '
-                                            'the series contain holes? If you are using a constructor method, '
+                                            'the series contain holes? If you are using a factory method, '
                                             'try specifying `fill_missing_dates=True` '
                                             'or specify the `freq` parameter.', logger)
         else:
@@ -113,7 +108,7 @@ class TimeSeries:
 
     @staticmethod
     def from_xarray(xa: xr.DataArray,
-                    fill_missing_dates: Optional[bool] = True,
+                    fill_missing_dates: Optional[bool] = False,
                     freq: Optional[str] = None) -> 'TimeSeries':
         """
         Returns a TimeSeries instance built from an xarray DataArray.
@@ -121,6 +116,11 @@ class TimeSeries:
         dimension can have an arbitrary name, but component and sample must be named "component" and "sample",
         respectively.
 
+        The first dimension (time), and second dimension (component) must be indexed (i.e., have coordinates).
+        The time must be indexed either with a pandas DatetimeIndex or a pandas Int64Index. If a DatetimeIndex is
+        used, it is better if it has no holes; although setting `fill_missing_dates` can in some cases solve these
+        issues (filling holes with NaN) at a performance cost.
+
         If two components have the same name or are not strings, this method will disambiguate the components
         names by appending a suffix of the form "<name>_N" to the N-th column with name "name".
 
@@ -131,6 +131,7 @@ class TimeSeries:
         fill_missing_dates
             Optionally, a boolean value indicating whether to fill missing dates with NaN values. This requires
             either a provided `freq` or the possibility to infer the frequency from the provided timestamps.
+            Inferring the frequency and resampling the data can induce a significant performance overhead.
         freq
             Optionally, a string representing the frequency of the Pandas DataFrame. This is useful in order to fill
             in missing values if some dates are missing and `fill_missing_dates` is set to `True`.
@@ -141,12 +142,15 @@ class TimeSeries:
             A univariate or multivariate deterministic TimeSeries constructed from the inputs.
         """
 
-        # optionally fill missing dates; do it only when there is a DatetimeIndex (and not a RangeIndex)
+        # optionally fill missing dates; do it only when there is a DatetimeIndex (and not a Int64Index)
         if fill_missing_dates and isinstance(xa.get_index(xa.dims[0]), pd.DatetimeIndex):
             sorted_xa = xa.sortby(xa.dims[0])
             time_index = sorted_xa.get_index(xa.dims[0])
 
             if not freq:
+                # FIXME: This is taking long, especially on longer series
+                # FIXME: both constructing observed_frequencies, as well as resampling the DataArray are taking long
+                # FIXME: can we do better?
                 samples_size = 3
                 observed_frequencies = [
                     time_index[x:x + samples_size].inferred_freq
@@ -165,8 +169,13 @@ class TimeSeries:
 
                 freq = observed_frequencies.pop()
 
-            # TODO: if provided freq doesn't match the freq in index either raise an error or correct
             xa_ = sorted_xa.resample({xa.dims[0]: freq}).asfreq()
+
+        elif isinstance(xa.get_index(xa.dims[0]), pd.DatetimeIndex) and \
+                freq is not None and \
+                xa.get_index(xa.dims[0]).freq is None:
+            # The provided index does not have a freq; using the provided freq
+            xa_ = xa.resample({xa.dims[0]: freq}).asfreq()
         else:
             xa_ = xa
 
@@ -215,7 +224,7 @@ class TimeSeries:
     def from_dataframe(df: pd.DataFrame,
                        time_col: Optional[str] = None,
                        value_cols: Optional[Union[List[str], str]] = None,
-                       fill_missing_dates: Optional[bool] = True,
+                       fill_missing_dates: Optional[bool] = False,
                        freq: Optional[str] = None,) -> 'TimeSeries':
         """
         Returns a deterministic TimeSeries instance built from a selection of columns of a DataFrame.
@@ -229,13 +238,16 @@ class TimeSeries:
         time_col
             The time column name. If set, the column will be cast to a pandas DatetimeIndex.
             If not set, the DataFrame index will be used. In this case the DataFrame must contain an index that is
-            either a pandas DatetimeIndex or a pandas RangeIndex.
+            either a pandas DatetimeIndex or a pandas Int64Index (incl. RangeIndex). If a DatetimeIndex is
+            used, it is better if it has no holes; although setting `fill_missing_dates` can in some cases solve these
+            issues (filling holes with NaN) at a performance cost.
         value_cols
             A string or list of strings representing the value column(s) to be extracted from the DataFrame. If set to
             `None`, the whole DataFrame will be used.
         fill_missing_dates
             Optionally, a boolean value indicating whether to fill missing dates with NaN values. This requires
             either a provided `freq` or the possibility to infer the frequency from the provided timestamps.
+            Inferring the frequency and resampling the data can induce a significant performance overhead.
         freq
             Optionally, a string representing the frequency of the Pandas DataFrame. This is useful in order to fill
             in missing values if some dates are missing and `fill_missing_dates` is set to `True`.
@@ -258,9 +270,9 @@ class TimeSeries:
         if time_col:
             time_index = pd.DatetimeIndex(df[time_col])
         else:
-            raise_if_not(isinstance(df.index, pd.RangeIndex) or isinstance(df.index, pd.DatetimeIndex),
+            raise_if_not(isinstance(df.index, pd.Int64Index) or isinstance(df.index, pd.DatetimeIndex),
                          'If time_col is not specified, the DataFrame must be indexed either with'
-                         'a DatetimeIndex, or with a RangeIndex.', logger)
+                         'a DatetimeIndex, or with a Int64Index (incl. RangeIndex).', logger)
             time_index = df.index
 
         if not time_index.name:
@@ -274,11 +286,16 @@ class TimeSeries:
 
     @staticmethod
     def from_series(pd_series: pd.Series,
-                    fill_missing_dates: Optional[bool] = True,
+                    fill_missing_dates: Optional[bool] = False,
                     freq: Optional[str] = None,) -> 'TimeSeries':
         """
         Returns a univariate and deterministic TimeSeries built from a pandas Series.
 
+        The series must contain an index that is
+        either a pandas DatetimeIndex or a pandas Int64Index (incl. RangeIndex). If a DatetimeIndex is
+        used, it is better if it has no holes; although setting `fill_missing_dates` can in some cases solve these
+        issues (filling holes with NaN) at a performance cost.
+
         Parameters
         ----------
         pd_series
@@ -286,6 +303,7 @@ class TimeSeries:
         fill_missing_dates
             Optionally, a boolean value indicating whether to fill missing dates with NaN values. This requires
             either a provided `freq` or the possibility to infer the frequency from the provided timestamps.
+            Inferring the frequency and resampling the data can induce a significant performance overhead.
         freq
             Optionally, a string representing the frequency of the Pandas DataFrame. This is useful in order to fill
             in missing values if some dates are missing and `fill_missing_dates` is set to `True`.
@@ -304,9 +322,9 @@ class TimeSeries:
                                          freq=freq)
 
     @staticmethod
-    def from_times_and_values(times: Union[pd.DatetimeIndex, pd.RangeIndex],
+    def from_times_and_values(times: Union[pd.DatetimeIndex, pd.Int64Index],
                               values: np.ndarray,
-                              fill_missing_dates: Optional[bool] = True,
+                              fill_missing_dates: Optional[bool] = False,
                               freq: Optional[str] = None,
                               columns: Optional[pd._typing.Axes] = None) -> 'TimeSeries':
         """
@@ -315,7 +333,10 @@ class TimeSeries:
         Parameters
         ----------
         times
-            A `pandas.DateTimeIndex` or `pandas.RangeIndex` representing the time axis for the time series.
+            A `pandas.DateTimeIndex` or `pandas.Int64Index` (or `pandas.RangeIndex`) representing the time axis
+            for the time series. If a DatetimeIndex is
+            used, it is better if it has no holes; although setting `fill_missing_dates` can in some cases solve these
+            issues (filling holes with NaN) at a performance cost.
         values
             A Numpy array of values for the TimeSeries. Both 2-dimensional arrays, for deterministic series,
             and 3-dimensional arrays, for probabilistic series, are accepted. In the former case the dimensions
@@ -323,6 +344,7 @@ class TimeSeries:
         fill_missing_dates
             Optionally, a boolean value indicating whether to fill missing dates with NaN values. This requires
             either a provided `freq` or the possibility to infer the frequency from the provided timestamps.
+            Inferring the frequency and resampling the data can induce a significant performance overhead.
         freq
             Optionally, a string representing the frequency of the Pandas DataFrame. This is useful in order to fill
             in missing values if some dates are missing and `fill_missing_dates` is set to `True`.
@@ -335,8 +357,8 @@ class TimeSeries:
             A TimeSeries constructed from the inputs.
         """
 
-        raise_if_not(isinstance(times, pd.RangeIndex) or isinstance(times, pd.DatetimeIndex),
-                     'the `times` argument must be a RangeIndex or a DateTimeIndex. Use '
+        raise_if_not(isinstance(times, pd.Int64Index) or isinstance(times, pd.DatetimeIndex),
+                     'the `times` argument must be a Int64Index (or RangeIndex), or a DateTimeIndex. Use '
                      'TimeSeries.from_values() if you want to use an automatic RangeIndex.')
 
         times_name = DIMS[0] if not times.name else times.name
@@ -359,9 +381,34 @@ class TimeSeries:
 
     @staticmethod
     def from_values(values: np.ndarray,
-                    fill_missing_dates: Optional[bool] = True,
+                    fill_missing_dates: Optional[bool] = False,
                     freq: Optional[str] = None,
                     columns: Optional[pd._typing.Axes] = None) -> 'TimeSeries':
+        """
+        Returns a TimeSeries built from an array of values.
+        The series will have an integer index (Int64Index).
+
+        Parameters
+        ----------
+        values
+            A Numpy array of values for the TimeSeries. Both 2-dimensional arrays, for deterministic series,
+            and 3-dimensional arrays, for probabilistic series, are accepted. In the former case the dimensions
+            should be (time, component), and in the latter case (time, component, sample).
+        fill_missing_dates
+            Optionally, a boolean value indicating whether to fill missing dates with NaN values. This requires
+            either a provided `freq` or the possibility to infer the frequency from the provided timestamps.
+            Inferring the frequency and resampling the data can induce a significant performance overhead.
+        freq
+            Optionally, a string representing the frequency of the Pandas DataFrame. This is useful in order to fill
+            in missing values if some dates are missing and `fill_missing_dates` is set to `True`.
+        columns
+            Columns to be used by the underlying pandas DataFrame.
+
+        Returns
+        -------
+        TimeSeries
+            A TimeSeries constructed from the inputs.
+        """
 
         time_index = pd.RangeIndex(0, len(values), 1)
 
@@ -453,11 +500,11 @@ class TimeSeries:
         return self.components
 
     @property
-    def time_index(self) -> Union[pd.DatetimeIndex, pd.RangeIndex]:
+    def time_index(self) -> Union[pd.DatetimeIndex, pd.Int64Index]:
         """
         Returns
         -------
-        Union[pd.DatetimeIndex, pd.RangeIndex]
+        Union[pd.DatetimeIndex, pd.Int64Index]
             The time index of this time series.
         """
         return self._time_index.copy()
@@ -465,14 +512,14 @@ class TimeSeries:
     @property
     def has_datetime_index(self) -> bool:
         """
-        Whether this series is indexed with a DatetimeIndex (otherwise it is indexed with a RangeIndex)
+        Whether this series is indexed with a DatetimeIndex (otherwise it is indexed with an Int64Index)
         """
         return self._has_datetime_index
 
     @property
     def has_range_index(self) -> bool:
         """
-        Whether this series is indexed with a RangeIndex (otherwise it is indexed with a DatetimeIndex)
+        Whether this series is indexed with an Int64Index (otherwise it is indexed with a DatetimeIndex)
         """
         return not self._has_datetime_index
 
@@ -691,7 +738,7 @@ class TimeSeries:
         -------
         Union[pandas.Timestamp, int]
             A timestamp containing the first time of the TimeSeries (if indexed by DatetimeIndex),
-            or an integer (if indexed by RangeIndex)
+            or an integer (if indexed by Int64Index/RangeIndex)
         """
         return self._time_index[0]
 
@@ -701,7 +748,7 @@ class TimeSeries:
         -------
         Union[pandas.Timestamp, int]
             A timestamp containing the last time of the TimeSeries (if indexed by DatetimeIndex),
-            or an integer (if indexed by RangeIndex)
+            or an integer (if indexed by Int64Index/RangeIndex)
         """
         return self._time_index[-1]
 
@@ -898,7 +945,7 @@ class TimeSeries:
         if isinstance(point, float):
             raise_if_not(0. <= point <= 1., 'point (float) should be between 0.0 and 1.0.', logger)
             point_index = int((len(self) - 1) * point)
-        elif isinstance(point, int):
+        elif isinstance(point, (int, np.int64)):
             raise_if(point not in range(len(self)), "point (int) should be a valid index in series", logger)
             point_index = point
         elif isinstance(point, pd.Timestamp):
@@ -916,7 +963,7 @@ class TimeSeries:
 
     def get_timestamp_at_point(self, point: Union[pd.Timestamp, float, int]) -> pd.Timestamp:
         """
-        Converts a point into a pandas.Timestamp in the time series
+        Converts a point into a pandas.Timestamp (if Datetime-indexed) or into an integer (if Int64-indexed).
 
         Parameters
         ----------
@@ -929,8 +976,6 @@ class TimeSeries:
             In case of a `pandas.Timestamp`, point will be returned as is provided that the timestamp
             is present in the series time index, otherwise will raise a ValueError.
         """
-        raise_if_not(self._has_datetime_index, 'Called get_timestamp_at_point() but this series '
-                                               'is not indexed with a DatetimeIndex.', logger)
         idx = self.get_index_at_point(point)
         return self._time_index[idx]
 
@@ -1038,7 +1083,7 @@ class TimeSeries:
                                                      'same type.', logger)
         if isinstance(start_ts, pd.Timestamp):
             raise_if_not(self._has_datetime_index, 'Timestamps have been provided to slice(), but the series is '
-                                                   'indexed using an integer-based RangeIndex.', logger)
+                                                   'indexed using an integer-based Int64Index.', logger)
             idx = pd.DatetimeIndex(filter(lambda t: start_ts <= t <= end_ts, self._time_index))
         else:
             raise_if(self._has_datetime_index, 'start and end times have been provided as integers to slice(), but '
@@ -1067,7 +1112,7 @@ class TimeSeries:
         raise_if_not(n > 0, 'n should be a positive integer.', logger)
         self._raise_if_not_within(start_ts)
 
-        if isinstance(start_ts, int):
+        if isinstance(start_ts, (int, np.int64)):
             return self[start_ts:start_ts+n]
         elif isinstance(start_ts, pd.Timestamp):
             # get first timestamp greater or equal to start_ts
@@ -1099,7 +1144,7 @@ class TimeSeries:
         raise_if_not(n > 0, 'n should be a positive integer.', logger)
         self._raise_if_not_within(end_ts)
 
-        if isinstance(end_ts, int):
+        if isinstance(end_ts, (int, np.int64)):
             return self[end_ts-n+1:end_ts+1]
         elif isinstance(end_ts, pd.Timestamp):
             # get last timestamp smaller or equal to start_ts
@@ -1226,7 +1271,7 @@ class TimeSeries:
         TimeSeries
             A new TimeSeries, with a shifted index.
         """
-        if not isinstance(n, int):
+        if not isinstance(n, (int, np.int64)):
             logger.warning(f"TimeSeries.shift(): converting n to int from {n} to {int(n)}")
             n = int(n)
 
@@ -1318,7 +1363,7 @@ class TimeSeries:
             A new TimeSeries, obtained by appending the second TimeSeries to the first.
         """
         raise_if_not(other.has_datetime_index == self.has_datetime_index,
-                     'Both series must have the same type of time index (either DatetimeIndex or RangeIndex).', logger)
+                     'Both series must have the same type of time index (either DatetimeIndex or Int64Index).', logger)
         raise_if_not(other.freq == self.freq,
                      'Appended TimeSeries must have the same frequency as the current one', logger)
         raise_if_not(other.n_components == self.n_components,
@@ -1340,6 +1385,7 @@ class TimeSeries:
         if not self._has_datetime_index:
             new_xa = new_xa.reset_index(dims_or_levels=new_xa.dims[0])
 
+        # TODO: fill_missing_dates takes a performance hit; do we need it here
         return TimeSeries.from_xarray(new_xa, fill_missing_dates=True, freq=self._freq_str)
 
     def append_values(self, values: np.ndarray) -> 'TimeSeries':
@@ -1544,7 +1590,7 @@ class TimeSeries:
         Parameters
         ----------
         ts
-            The `pandas.Timestamp` (if indexed with DatetimeIndex) or integer (if indexed with RangeIndex) to check.
+            The `pandas.Timestamp` (if indexed with DatetimeIndex) or integer (if indexed with Int64Index) to check.
 
         Returns
         -------
@@ -1569,7 +1615,7 @@ class TimeSeries:
             Either a function which takes a value and returns a value ie. `f(x) = y`
             Or a function which takes a value and its timestamp and returns a value ie. `f(timestamp, x) = y`
             The type of `timestamp` is either `pd.Timestamp` (if the series is indexed with a DatetimeIndex),
-            or an integer otherwise (if the series is indexed with a RangeIndex).
+            or an integer otherwise (if the series is indexed with an Int64Index).
 
         Returns
         -------
@@ -1921,7 +1967,7 @@ class TimeSeries:
 
     def __getitem__(self,
                     key: Union[pd.DatetimeIndex,
-                               pd.RangeIndex,
+                               pd.Int64Index,
                                List[str],
                                List[int],
                                List[pd.Timestamp],
@@ -1936,7 +1982,7 @@ class TimeSeries:
         - str -> return a TimeSeries including the column(s) (components) specified as str.
         - int -> return a TimeSeries with the value(s) at the given row (time) index.
 
-        `pd.DatetimeIndex` and `pd.RangeIndex` are also supported and will return the corresponding value(s)
+        `pd.DatetimeIndex` and `pd.Int64Index` are also supported and will return the corresponding value(s)
         at the provided time indices.
 
         .. warning::
@@ -1944,10 +1990,10 @@ class TimeSeries:
         """
         def _check_dt():
             raise_if_not(self._has_datetime_index, 'Attempted indexing a series with a DatetimeIndex or a timestamp, '
-                                                   'but the series uses a RangeIndex.', logger)
+                                                   'but the series uses an Int64Index.', logger)
 
         def _check_range():
-            raise_if(self._has_datetime_index, 'Attempted indexing a series with a RangeIndex, '
+            raise_if(self._has_datetime_index, 'Attempted indexing a series with an Int64Index, '
                                                'but the series uses a DatetimeIndex.', logger)
 
         def _set_freq_in_xa(xa_: xr.DataArray):
@@ -1958,7 +2004,7 @@ class TimeSeries:
             else:
                 xa_.get_index(self._time_dim).freq = self._freq
 
-        # handle DatetimeIndex and RangeIndex:
+        # handle DatetimeIndex and Int64Index:
         if isinstance(key, pd.DatetimeIndex):
             _check_dt()
             xa_ = self._xa.sel({self._time_dim: key})
@@ -1968,7 +2014,7 @@ class TimeSeries:
             _set_freq_in_xa(xa_)
 
             return TimeSeries(xa_)
-        elif isinstance(key, pd.RangeIndex):
+        elif isinstance(key, pd.Int64Index):
             _check_range()
             return TimeSeries(self._xa.sel({self._time_dim: key}))
 
@@ -1976,7 +2022,7 @@ class TimeSeries:
         elif isinstance(key, slice):
             if isinstance(key.start, str) or isinstance(key.stop, str):
                 return TimeSeries(self._xa.sel({DIMS[1]: key}))
-            elif isinstance(key.start, int) or isinstance(key.stop, int):
+            elif isinstance(key.start, (int, np.int64)) or isinstance(key.stop, (int, np.int64)):
                 return TimeSeries(self._xa.isel({self._time_dim: key}))
             elif isinstance(key.start, pd.Timestamp) or isinstance(key.stop, pd.Timestamp):
                 _check_dt()
@@ -1989,7 +2035,7 @@ class TimeSeries:
         # handle simple types:
         elif isinstance(key, str):
             return TimeSeries(self._xa.sel({DIMS[1]: [key]}))  # have to put key in a list not to drop the dimension
-        elif isinstance(key, int):
+        elif isinstance(key, (int, np.int64)):
             return TimeSeries(self._xa.isel({self._time_dim: [key]}))
         elif isinstance(key, pd.Timestamp):
             _check_dt()
@@ -2004,7 +2050,7 @@ class TimeSeries:
             if all(isinstance(s, str) for s in key):
                 # when string(s) are provided, we consider it as (a list of) component(s)
                 return TimeSeries(self._xa.sel({DIMS[1]: key}))
-            elif all(isinstance(i, int) for i in key):
+            elif all(isinstance(i, (int, np.int64)) for i in key):
                 return TimeSeries(self._xa.isel({self._time_dim: key}))
             elif all(isinstance(t, pd.Timestamp) for t in key):
                 _check_dt()
