@@ -9,9 +9,9 @@ def read_requirements(path):
 base_reqs = read_requirements('requirements/core.txt')
 pmdarima_reqs = read_requirements('requirements/pmdarima.txt')
 torch_reqs = read_requirements('requirements/torch.txt')
-fbprophet_reqs = read_requirements('requirements/fbprophet.txt')
+prophet_reqs = read_requirements('requirements/prophet.txt')
 
-all_reqs = base_reqs + pmdarima_reqs + torch_reqs + fbprophet_reqs
+all_reqs = base_reqs + pmdarima_reqs + torch_reqs + prophet_reqs
 
 with open("README.md", "r") as fh:
     LONG_DESCRIPTION = fh.read()
@@ -29,7 +29,7 @@ PROJECT_URLS = {
 
 setup(
       name='u8darts',
-      version="0.9.0",
+      version="0.9.1",
       description='A python library for easy manipulation and forecasting of time series.',
       long_description=LONG_DESCRIPTION,
       long_description_content_type="text/markdown",
@@ -44,7 +44,7 @@ setup(
             'all': all_reqs,
             'pmdarima': pmdarima_reqs,
             'torch': torch_reqs,
-            'fbprophet': fbprophet_reqs,
+            'prophet': prophet_reqs,
       },
       package_data={
           'darts': ['py.typed'],
